/*
stattest - tests for randomness
Copyright (C) 2003  Roland Siegert, Andreas Stricker

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
*/

/** \file
 * \brief Module bias: Calculate bias of a sequence
 *
 * Calculate the bias of a sequence in buffer.
 *
 * \author Andreas Stricker
 * \author Roland Siegert
 * \version $Id: bias.c,v 1.5 2003/05/15 07:54:54 stricand Exp $
 */
 
#include <stdlib.h>

#include "bias.h"
#include "stattest.h"

/** \brief Calculate the bias of the buffer.
 * The bias calculation is accelerated by using a precalculated look-up table.
 * \param buf the buffer with random data
 * \param buf_len length of the buffer
 * \return the bias of the data relatet to a single bit. True Random should
 *          return 0.5
 */
double calc_bias(buffer_t buf, size_t buf_len) {
	block_t lookuptable[BLOCK_RANGE];	// filled with number of "1" in the
										// index-number
	long count;							// counter
	size_t i;							// for () index
	int j, n;							// for () index
	double bias;						// bias of the data in buffer

	bias = 0.0;							// default value

	if (buf_len <= 0) return bias;		// no size, return zero

	// build look-up table
	for (j = 0; j < BLOCK_RANGE; j++) {
		count = 0;
		for (n = 0; n < BLOCK_LENGTH; n++) count += ((j >> n) & 0x01);
		lookuptable[j] = (block_t) count;
	}
	// count number of logic "1" in block
	count = 0;
	for (i = 0; i < buf_len; i++) count += lookuptable[buf[i]];
	// finally calculate bias
	bias = ((double) count) / (buf_len*BLOCK_LENGTH);
	
	return bias;
} // calc_bias
