/*
stattest - tests for randomness
Copyright (C) 2003  Roland Siegert, Andreas Stricker

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
*/

/** \file
 * \brief Standard deviation interpolation from table
 *
 * Calculate standard deviation with a table an additional
 * linear interpolation between values
 *
 * \author Andreas Stricker
 * \author Roland Siegert
 * \version $Id: stddeviation.h,v 1.4 2003/05/15 07:54:54 stricand Exp $
 */

#ifndef STDDEVIATION_H_920A
#define STDDEVIATION_H_920A

/** \brief Interpolate standard deviation N(x) for x in [0..4]
 * Lookup nearst values from x in the table and interpolates linear
 * between them.
 * \param x Value of Integrals N(x) between -infinity and x, must be
 *           in range [0..4]
 * \return -1.0 if x is out of Range, else the value of the integral
 * \sa inv_standard_deviation()
 */
double standard_deviation(double x);

/** \brief Search the inverse of the function N(x).
 * Binary search a y where 1.0 - N(y) = p/2
 * \param p the area under the normal distribution function
 * \return the pos x where the area is = p/2
 * \sa standard_deviation()
 */
double inv_standard_deviation(double p);

#endif
